@@ -3,6 +3,8 @@ from django import forms
 from django.conf import settings
 from django.utils.translation import get_language
 
+from django_libs.loaders import load_member
+
 from .models import Review, Rating, RatingCategory
 
 
@@ -10,7 +12,10 @@ class ReviewForm(forms.ModelForm):
     def __init__(self, reviewed_item, user=None, *args, **kwargs):
         self.user = user
         self.reviewed_item = reviewed_item
-        self.widget = getattr(settings, 'REVIEW_FORM_CHOICE_WIDGET', None)
+        self.widget = load_member(
+            getattr(settings, 'REVIEW_FORM_CHOICE_WIDGET',
+                    'django.forms.widgets.Select')
+        )()
         super(ReviewForm, self).__init__(*args, **kwargs)
         # Dynamically add fields for each rating category
         for category in RatingCategory.objects.all():
@@ -19,10 +24,9 @@ class ReviewForm(forms.ModelForm):
             self.fields[field_name] = forms.ChoiceField(
                 choices=choices, label=category.name,
                 help_text=category.question,
+                widget=self.widget,
             )
             self.fields[field_name].required = category.required
-            if self.widget is not None:
-                self.fields[field_name].widget = self.widget()
             if self.instance.pk:
                 try:
                     self.initial.update({
